@@ -38,18 +38,18 @@ __all__ = ("ListProfileTimesPaginator",)
 
 class ListProfileTimesPaginator(Boto3Paginator):
     """
-    [Paginator.ListProfileTimes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.21/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
+    [Paginator.ListProfileTimes documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.25/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes)
     """
 
     def paginate(
         self,
         endTime: datetime,
-        period: Literal["P1D", "PT1H", "PT5M"],
+        period: Literal["PT5M", "PT1H", "P1D"],
         profilingGroupName: str,
         startTime: datetime,
-        orderBy: Literal["TimestampAscending", "TimestampDescending"] = None,
+        orderBy: Literal["TimestampDescending", "TimestampAscending"] = None,
         PaginationConfig: PaginatorConfigTypeDef = None,
     ) -> Iterator[ListProfileTimesResponseTypeDef]:
         """
-        [ListProfileTimes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.21/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes.paginate)
+        [ListProfileTimes.paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.17.25/reference/services/codeguruprofiler.html#CodeGuruProfiler.Paginator.ListProfileTimes.paginate)
         """
